Reviewer Goals
==============

* Collaborate with content creators to ensure the quality and timeliness of
  site content.

- :doc:`BrowseSubmittedForReview`

  - Brief description of the Action box, with pointers back to
     where this is set up in the skin.

  - Pending lists

- :doc:`ApproveForPublication`

    This should mainly be a pointer back into "Browse content
    submitted for review and publication"

* React quickly to resolve issues with published content.

  - :doc:`UnpublishContent`

